==> mcu_plus_sdk_am263x_08_06_00_34_docs_only.tar.xz: mcu_plus_sdk_am263x_08_06_00_34_docs_only/docs/api_guide_am263x/group__DRV__QSPI__MODULE.js <==
var group__DRV__QSPI__MODULE =
[
    [ "qspi/v0/qspi.h", "qspi_2v0_2qspi_8h.html", null ],
    [ "QSPI_Transaction", "structQSPI__Transaction.html", [
      [ "count", "structQSPI__Transaction.html#a22e0c71cf30d786f5d79524caa15f454", null ],
      [ "buf", "structQSPI__Transaction.html#a7dde0aff7b7ef86e12dbcff402dd6224", null ],
      [ "addrOffset", "structQSPI__Transaction.html#a723558d1180bbf8fb8a2af23dd092f31", null ],
      [ "status", "structQSPI__Transaction.html#a1fd7ea54a8abf300c6aabac9a5bfe243", null ],
      [ "transferTimeout", "structQSPI__Transaction.html#a9aa227c6e2c87fd862eef22e68a8104c", null ]
    ] ],
    [ "QSPI_ReadCmdParams", "structQSPI__ReadCmdParams.html", [
      [ "cmd", "structQSPI__ReadCmdParams.html#aaa0f0a942ea666f1ed07d244bb6e9925", null ],
      [ "cmdAddr", "structQSPI__ReadCmdParams.html#afb327084060da479e4718a8521007afc", null ],
      [ "numAddrBytes", "structQSPI__ReadCmdParams.html#a12a4c7da6ab32e8d91da18b67d76ba41", null ],
      [ "rxDataBuf", "structQSPI__ReadCmdParams.html#a65f1bd3bd95ab0e3856228a292ac1ef7", null ],
      [ "rxDataLen", "structQSPI__ReadCmdParams.html#ad5066e648b004376dbdd34446d7b3661", null ]
    ] ],
    [ "QSPI_WriteCmdParams", "structQSPI__WriteCmdParams.html", [
      [ "cmd", "structQSPI__WriteCmdParams.html#a7db37628db15219d25574b76ba89b5b4", null ],
      [ "cmdAddr", "structQSPI__WriteCmdParams.html#a0de3e2a5d3c2bce702871612303fe42e", null ],
      [ "numAddrBytes", "structQSPI__WriteCmdParams.html#ac7c12c21a442981ab73e086028020693", null ],
      [ "txDataBuf", "structQSPI__WriteCmdParams.html#a1b13e9b99c72bce7f2e1b87367354752", null ],
      [ "txDataLen", "structQSPI__WriteCmdParams.html#a85f7eb398cefac4c1595deae18680037", null ]
    ] ],
    [ "QSPI_Params", "structQSPI__Params.html", [
      [ "edmaInst", "structQSPI__Params.html#ad90bf885d828c1727aeaab0efdddce3e", null ]
    ] ],
    [ "QSPI_EdmaParams", "structQSPI__EdmaParams.html", [
      [ "edmaTcc", "structQSPI__EdmaParams.html#a5b1736dcc6bb607e63f5f0b3cb1a2407", null ],
      [ "edmaChId", "structQSPI__EdmaParams.html#a74c3b909f0d35b59a3cf963f0375abaa", null ],
      [ "edmaParam", "structQSPI__EdmaParams.html#a19ea77aa6ddf4025750e42cd1dffac78", null ],
      [ "edmaRegionId", "structQSPI__EdmaParams.html#a703028d36016b86ac58cf0cd649af172", null ],
      [ "edmaBaseAddr", "structQSPI__EdmaParams.html#a3b0a7d15ea111acbf521d039eb843cf9", null ],
      [ "isIntEnabled", "structQSPI__EdmaParams.html#a7ff6a54b5572677dbcc202ed5005b406", null ],
      [ "edmaIntrObj", "structQSPI__EdmaParams.html#a271aa1938f36d63d66fde6e918e07df3", null ],
      [ "gEdmaTransferDoneSem", "structQSPI__EdmaParams.html#aa6b7ac5cf09218423f82014d7546c768", null ]
    ] ],
    [ "QSPI_Object", "structQSPI__Object.html", [
      [ "handle", "structQSPI__Object.html#ab96a83ca903747c5d8a9c71fa934ca07", null ],
      [ "transferMode", "structQSPI__Object.html#a0d281fe244310d5b55b21cd4f114a279", null ],
      [ "rxLines", "structQSPI__Object.html#acaec5bf4d4aca63a194052086ab62121", null ],
      [ "readCmd", "structQSPI__Object.html#aa2784aac232611ca16a3fb577cd8e2de", null ],
      [ "writeCmd", "structQSPI__Object.html#a5ae1170ac0c30b72dca84fd28ef70887", null ],
      [ "frmLength", "structQSPI__Object.html#afb9f43a09f1a9eb989ef0f69d9782369", null ],
      [ "numAddrBytes", "structQSPI__Object.html#aa6eb95c1046107c3641d7a0808412e75", null ],
      [ "numDummyBits", "structQSPI__Object.html#a059c4d91ce148cc061ababc4a08c08a6", null ],
      [ "qspiEdmaParams", "structQSPI__Object.html#ace1378dae2f8b7588f08432389c817a1", null ],
      [ "qspiEdmaHandle", "structQSPI__Object.html#a0866c646a8071a57898c7c3ad8f2325d", null ],
      [ "isOpen", "structQSPI__Object.html#a1552642610edd244d5df0d5b31b0d193", null ],
      [ "lockObj", "structQSPI__Object.html#ab888626c0f00284dd7907244fbca6e8b", null ],
      [ "transferSemObj", "structQSPI__Object.html#aa4de9298fb207162625b566755dbedec", null ],
      [ "hwiObj", "structQSPI__Object.html#aa3e3acdfd429fb952207c429710fabaf", null ],
      [ "transaction", "structQSPI__Object.html#a9a45b12a51073361d764199dd622f993", null ]
    ] ],
    [ "QSPI_Attrs", "structQSPI__Attrs.html", [
      [ "baseAddr", "structQSPI__Attrs.html#a4b37f417be4d064b56fce114fd7110b3", null ],
      [ "memMapBaseAddr", "structQSPI__Attrs.html#a425df6b055419f7b8d650e2a75d6a123", null ],
      [ "inputClkFreq", "structQSPI__Attrs.html#a5c645b4f0b29dce9733d1e905684b04b", null ],
      [ "baudRateDiv", "structQSPI__Attrs.html#af5fd4e04a4484f66d7031e5c63ce28c5", null ],
      [ "chipSelect", "structQSPI__Attrs.html#af947aecce260327e47dc9b957f6752ff", null ],
      [ "csPol", "structQSPI__Attrs.html#ac113c9c0aa2d54b0392dfa752daf062d", null ],
      [ "frmFmt", "structQSPI__Attrs.html#a501fcf53ee3fe0f1d65ea2baa7f789d6", null ],
      [ "dataDelay", "structQSPI__Attrs.html#ac1b46b68674d930136eb13b9120a56cc", null ],
      [ "rxLines", "structQSPI__Attrs.html#aa8bda413fe705f717652bbc7b2e921c4", null ],
      [ "wrdLen", "structQSPI__Attrs.html#a60efd9c8dace4ef88953c4a81f83fca4", null ],
      [ "intrNum", "structQSPI__Attrs.html#a68c38726087a85bc38710b4758ef21c1", null ],
      [ "intrEnable", "structQSPI__Attrs.html#a1a441c3962309a5738c9a19b9e887200", null ],
      [ "intrPriority", "structQSPI__Attrs.html#a699365d37aaa6df6b2f0f01ea67125be", null ],
      [ "dmaEnable", "structQSPI__Attrs.html#a158c423d43b8dc0beb9b3ac9bebd9cfc", null ]
    ] ],
    [ "QSPI_Config", "structQSPI__Config.html", [
      [ "attrs", "structQSPI__Config.html#a6f42684beb03f2c5271f5fe303665f20", null ],
      [ "object", "structQSPI__Config.html#ae560ef957a4957a9051dfa963d0f6b19", null ]
    ] ],
    [ "QSPI_CS0", "group__DRV__QSPI__MODULE.html#gad51c74dc620d55b0741bc48ecdf829b1", null ],
    [ "QSPI_CS1", "group__DRV__QSPI__MODULE.html#ga0fa2620feacc8a68f2cfdf82552273c1", null ],
    [ "QSPI_CS2", "group__DRV__QSPI__MODULE.html#gaae1d1efdb3b12926f58078b2fb64a4f2", null ],
    [ "QSPI_CS3", "group__DRV__QSPI__MODULE.html#ga03b45a0fe8d9eab48481359c0e25014f", null ],
    [ "QSPI_CMD_INVALID_OPCODE", "group__DRV__QSPI__MODULE.html#gadbead14f021366f61edfa01b47da20bd", null ],
    [ "QSPI_CMD_INVALID_ADDR", "group__DRV__QSPI__MODULE.html#ga0a592e34cd25ce8a65869b5533d45b56", null ],
    [ "QSPI_TRANSFER_COMPLETED", "group__DRV__QSPI__MODULE.html#ga4b2800deb09fe29d8e3d2316166726f1", null ],
    [ "QSPI_TRANSFER_STARTED", "group__DRV__QSPI__MODULE.html#gabd8a966c4f943460d557e75959ecdbf7", null ],
    [ "QSPI_TRANSFER_CANCELLED", "group__DRV__QSPI__MODULE.html#gaada781787ade5549173b7fd1cf19ddaf", null ],
    [ "QSPI_TRANSFER_FAILED", "group__DRV__QSPI__MODULE.html#gaad03c1c3a8b82bebb93cb51e273b79c2", null ],
    [ "QSPI_TRANSFER_CSN_DEASSERT", "group__DRV__QSPI__MODULE.html#ga3d512210a36aa93dde4934f8a39f0064", null ],
    [ "QSPI_TRANSFER_TIMEOUT", "group__DRV__QSPI__MODULE.html#ga28b0df7988185754e238242371bfb810", null ],
    [ "QSPI_RX_LINES_SINGLE", "group__DRV__QSPI__MODULE.html#ga1834ecaf8f3c844c53daf13e4e43328f", null ],
    [ "QSPI_RX_LINES_DUAL", "group__DRV__QSPI__MODULE.html#ga0451132523ca6a0bb951cac28a05da99", null ],
    [ "QSPI_RX_LINES_QUAD", "group__DRV__QSPI__MODULE.html#gade15e2e2fed7534de1d6ea260535cc28", null ],
    [ "QSPI_FF_POL0_PHA0", "group__DRV__QSPI__MODULE.html#ga9cf00ff499cd68dff088545495234339", null ],
    [ "QSPI_FF_POL0_PHA1", "group__DRV__QSPI__MODULE.html#ga716e71d38d62749eabbad7d9ed13290d", null ],
    [ "QSPI_FF_POL1_PHA0", "group__DRV__QSPI__MODULE.html#gac458fb8e4cbe6d24210505df62b16397", null ],
    [ "QSPI_FF_POL1_PHA1", "group__DRV__QSPI__MODULE.html#ga14f047b51b0ae9561479653e6ccd147c", null ],
    [ "QSPI_CS_POL_ACTIVE_LOW", "group__DRV__QSPI__MODULE.html#ga0318e627a246b2676a3804ee07d8bd30", null ],
    [ "QSPI_CS_POL_ACTIVE_HIGH", "group__DRV__QSPI__MODULE.html#gae5102933d2099c45a24a30258281b826", null ],
    [ "QSPI_DATA_DELAY_0", "group__DRV__QSPI__MODULE.html#ga9e474ea310d16cc61ffae0a043b0bb76", null ],
    [ "QSPI_DATA_DELAY_1", "group__DRV__QSPI__MODULE.html#gac6e3e204ce59030920b0ff49ee44f7c9", null ],
    [ "QSPI_DATA_DELAY_2", "group__DRV__QSPI__MODULE.html#ga07d869fae43fa8ac34c0db671f9453d0", null ],
    [ "QSPI_DATA_DELAY_3", "group__DRV__QSPI__MODULE.html#ga035cad27d3f8f8706ff3a881d127a600", null ],
    [ "QSPI_Handle", "group__DRV__QSPI__MODULE.html#ga4145712eccae1514baeb83a5af952b9b", null ],
    [ "QSPI_init", "group__DRV__QSPI__MODULE.html#ga1d19b7d7d62bf4434e0246095477f2b4", null ],
    [ "QSPI_deinit", "group__DRV__QSPI__MODULE.html#ga5c3ae76d3a0f2a6ea6ed1ac332d397b9", null ],
    [ "QSPI_Params_init", "group__DRV__QSPI__MODULE.html#ga1d6f4702b4a903b2f907789a59f5b87b", null ],
    [ "QSPI_open", "group__DRV__QSPI__MODULE.html#ga4ca75fea87230420859b5c8128492905", null ],
    [ "QSPI_close", "group__DRV__QSPI__MODULE.html#ga6d5f30a61e058ccd98e1c55439cc7c35", null ],
    [ "QSPI_getHandle", "group__DRV__QSPI__MODULE.html#ga7abf12320af4df4096677c4a355a02ca", null ],
    [ "QSPI_getInputClk", "group__DRV__QSPI__MODULE.html#gaf55858a05c9f61da9ad705059c6e5020", null ],
    [ "QSPI_readMemMapMode", "group__DRV__QSPI__MODULE.html#ga6466fe94253ee22d728409ca52357e8c", null ],
    [ "QSPI_writeConfigMode", "group__DRV__QSPI__MODULE.html#ga0d2b0006f7828a20021394d87aaa6b6d", null ],
    [ "QSPI_transaction_init", "group__DRV__QSPI__MODULE.html#ga66127f46974f1cab51726fe65e45ad2b", null ],
    [ "QSPI_readCmdParams_init", "group__DRV__QSPI__MODULE.html#ga931d517d31412aa543d7e2e3cffbe14a", null ],
    [ "QSPI_writeCmdParams_init", "group__DRV__QSPI__MODULE.html#gaddaabb30a400f9e894dec38b85c820e3", null ],
    [ "QSPI_readCmd", "group__DRV__QSPI__MODULE.html#gafca35047faaeec5b1926054181caea65", null ],
    [ "QSPI_writeCmd", "group__DRV__QSPI__MODULE.html#gae84861505dc2b319aa8920c451117521", null ],
    [ "QSPI_setWriteCmd", "group__DRV__QSPI__MODULE.html#ga4a009c6e0dc8ce61dc79b1084ddabae8", null ],
    [ "QSPI_setReadCmd", "group__DRV__QSPI__MODULE.html#gab5269bbc4e7db9c81a92b567331d9f46", null ],
    [ "QSPI_setAddressByteCount", "group__DRV__QSPI__MODULE.html#ga0b2a9061d878871f6053a684700dd092", null ],
    [ "QSPI_setDummyBitCount", "group__DRV__QSPI__MODULE.html#gabb52dd394b88a692dd59bfb4474205ec", null ],
    [ "QSPI_setMemAddrSpace", "group__DRV__QSPI__MODULE.html#gae12db59fc3483c599ccaceebce20120d", null ],
    [ "QSPI_intEnable", "group__DRV__QSPI__MODULE.html#gae9d37319d0eb17cdc31949e6ed52a6b5", null ],
    [ "QSPI_intDisable", "group__DRV__QSPI__MODULE.html#ga2df1d404c0ba42e1f148a9f991407cda", null ],
    [ "QSPI_intClear", "group__DRV__QSPI__MODULE.html#gafcb59a900781476e8009553130846529", null ],
    [ "QSPI_setPreScaler", "group__DRV__QSPI__MODULE.html#ga47e29eddcb2586a011365bd572c9fbf9", null ],
    [ "QSPI_setRxLines", "group__DRV__QSPI__MODULE.html#gaee55483cc68c6d1cf7e6c54b0f15cd5c", null ],
    [ "QSPI_getRxLines", "group__DRV__QSPI__MODULE.html#ga8e65cfdf9667880682291da055708b2c", null ],
    [ "OSPI_phyGetTuningData", "group__DRV__QSPI__MODULE.html#ga69d9a4b5df3d4a4f92321e77b2dc21e5", null ],
    [ "gQspiConfig", "group__DRV__QSPI__MODULE.html#ga883b4d2580730337ed7b9c755ce7a415", null ],
    [ "gQspiConfigNum", "group__DRV__QSPI__MODULE.html#gabc05cad3f8ccc0e25325ae6f30e97384", null ]
];

==> mcu_plus_sdk_am263x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am263x_11_01_00_19_docs_only/docs/api_guide_am263x/group__DRV__QSPI__MODULE.js <==
var group__DRV__QSPI__MODULE =
[
    [ "qspi/v0/qspi.h", "qspi_2v0_2qspi_8h.html", null ],
    [ "QSPI_Transaction", "structQSPI__Transaction.html", [
      [ "count", "structQSPI__Transaction.html#a22e0c71cf30d786f5d79524caa15f454", null ],
      [ "buf", "structQSPI__Transaction.html#a7dde0aff7b7ef86e12dbcff402dd6224", null ],
      [ "addrOffset", "structQSPI__Transaction.html#a723558d1180bbf8fb8a2af23dd092f31", null ],
      [ "status", "structQSPI__Transaction.html#a1fd7ea54a8abf300c6aabac9a5bfe243", null ],
      [ "transferTimeout", "structQSPI__Transaction.html#a9aa227c6e2c87fd862eef22e68a8104c", null ]
    ] ],
    [ "QSPI_ReadCmdParams", "structQSPI__ReadCmdParams.html", [
      [ "cmd", "structQSPI__ReadCmdParams.html#aaa0f0a942ea666f1ed07d244bb6e9925", null ],
      [ "cmdAddr", "structQSPI__ReadCmdParams.html#afb327084060da479e4718a8521007afc", null ],
      [ "numAddrBytes", "structQSPI__ReadCmdParams.html#a12a4c7da6ab32e8d91da18b67d76ba41", null ],
      [ "rxDataBuf", "structQSPI__ReadCmdParams.html#a65f1bd3bd95ab0e3856228a292ac1ef7", null ],
      [ "rxDataLen", "structQSPI__ReadCmdParams.html#ad5066e648b004376dbdd34446d7b3661", null ]
    ] ],
    [ "QSPI_WriteCmdParams", "structQSPI__WriteCmdParams.html", [
      [ "cmd", "structQSPI__WriteCmdParams.html#a7db37628db15219d25574b76ba89b5b4", null ],
      [ "cmdAddr", "structQSPI__WriteCmdParams.html#a0de3e2a5d3c2bce702871612303fe42e", null ],
      [ "numAddrBytes", "structQSPI__WriteCmdParams.html#ac7c12c21a442981ab73e086028020693", null ],
      [ "txDataBuf", "structQSPI__WriteCmdParams.html#a1b13e9b99c72bce7f2e1b87367354752", null ],
      [ "txDataLen", "structQSPI__WriteCmdParams.html#a85f7eb398cefac4c1595deae18680037", null ]
    ] ],
    [ "QSPI_Params", "structQSPI__Params.html", [
      [ "edmaInst", "structQSPI__Params.html#ad90bf885d828c1727aeaab0efdddce3e", null ]
    ] ],
    [ "QSPI_Object", "structQSPI__Object.html", [
      [ "handle", "structQSPI__Object.html#ab96a83ca903747c5d8a9c71fa934ca07", null ],
      [ "transferMode", "structQSPI__Object.html#a0d281fe244310d5b55b21cd4f114a279", null ],
      [ "rxLines", "structQSPI__Object.html#acaec5bf4d4aca63a194052086ab62121", null ],
      [ "readCmd", "structQSPI__Object.html#aa2784aac232611ca16a3fb577cd8e2de", null ],
      [ "writeCmd", "structQSPI__Object.html#a5ae1170ac0c30b72dca84fd28ef70887", null ],
      [ "frmLength", "structQSPI__Object.html#afb9f43a09f1a9eb989ef0f69d9782369", null ],
      [ "numAddrBytes", "structQSPI__Object.html#aa6eb95c1046107c3641d7a0808412e75", null ],
      [ "numDummyBits", "structQSPI__Object.html#a059c4d91ce148cc061ababc4a08c08a6", null ],
      [ "qspiEdmaHandle", "structQSPI__Object.html#a0866c646a8071a57898c7c3ad8f2325d", null ],
      [ "isOpen", "structQSPI__Object.html#a1552642610edd244d5df0d5b31b0d193", null ],
      [ "lockObj", "structQSPI__Object.html#ab888626c0f00284dd7907244fbca6e8b", null ],
      [ "transferSemObj", "structQSPI__Object.html#aa4de9298fb207162625b566755dbedec", null ],
      [ "hwiObj", "structQSPI__Object.html#aa3e3acdfd429fb952207c429710fabaf", null ],
      [ "transaction", "structQSPI__Object.html#a9a45b12a51073361d764199dd622f993", null ],
      [ "qspilldInitObject", "structQSPI__Object.html#a612372da80b5ea8f91641d2c5d5ef087", null ],
      [ "qspilldInitHandle", "structQSPI__Object.html#abebdc800ec94cfb2cecda2291f911257", null ],
      [ "qspilldObject", "structQSPI__Object.html#a0b7cc2d0cf3955de553219be2175af67", null ],
      [ "qspilldHandle", "structQSPI__Object.html#a69957f2817e2811b47734f7ab08542f1", null ]
    ] ],
    [ "QSPI_Attrs", "structQSPI__Attrs.html", [
      [ "baseAddr", "structQSPI__Attrs.html#a4b37f417be4d064b56fce114fd7110b3", null ],
      [ "memMapBaseAddr", "structQSPI__Attrs.html#a425df6b055419f7b8d650e2a75d6a123", null ],
      [ "inputClkFreq", "structQSPI__Attrs.html#a5c645b4f0b29dce9733d1e905684b04b", null ],
      [ "baudRateDiv", "structQSPI__Attrs.html#af5fd4e04a4484f66d7031e5c63ce28c5", null ],
      [ "chipSelect", "structQSPI__Attrs.html#af947aecce260327e47dc9b957f6752ff", null ],
      [ "csPol", "structQSPI__Attrs.html#ac113c9c0aa2d54b0392dfa752daf062d", null ],
      [ "frmFmt", "structQSPI__Attrs.html#a501fcf53ee3fe0f1d65ea2baa7f789d6", null ],
      [ "dataDelay", "structQSPI__Attrs.html#ac1b46b68674d930136eb13b9120a56cc", null ],
      [ "rxLines", "structQSPI__Attrs.html#aa8bda413fe705f717652bbc7b2e921c4", null ],
      [ "wrdLen", "structQSPI__Attrs.html#a60efd9c8dace4ef88953c4a81f83fca4", null ],
      [ "intrNum", "structQSPI__Attrs.html#a68c38726087a85bc38710b4758ef21c1", null ],
      [ "intrEnable", "structQSPI__Attrs.html#adf489b329f3a91367a80b557b15b3c5c", null ],
      [ "wordIntr", "structQSPI__Attrs.html#a30fe26947d298242739b25aa17253ee9", null ],
      [ "frameIntr", "structQSPI__Attrs.html#ac5016d339470c3ebb90cc4f7c470117f", null ],
      [ "intrPriority", "structQSPI__Attrs.html#a699365d37aaa6df6b2f0f01ea67125be", null ],
      [ "dmaEnable", "structQSPI__Attrs.html#a8f217f6b606e226eb4e8317406ffa979", null ]
    ] ],
    [ "QSPI_Config", "structQSPI__Config.html", [
      [ "attrs", "structQSPI__Config.html#a6f42684beb03f2c5271f5fe303665f20", null ],
      [ "object", "structQSPI__Config.html#ae560ef957a4957a9051dfa963d0f6b19", null ]
    ] ],
    [ "QSPI_CMD_INVALID_OPCODE", "group__DRV__QSPI__MODULE.html#gadbead14f021366f61edfa01b47da20bd", null ],
    [ "QSPI_CMD_INVALID_ADDR", "group__DRV__QSPI__MODULE.html#ga0a592e34cd25ce8a65869b5533d45b56", null ],
    [ "QSPI_TRANSFER_COMPLETED", "group__DRV__QSPI__MODULE.html#ga4b2800deb09fe29d8e3d2316166726f1", null ],
    [ "QSPI_TRANSFER_STARTED", "group__DRV__QSPI__MODULE.html#gabd8a966c4f943460d557e75959ecdbf7", null ],
    [ "QSPI_TRANSFER_CANCELLED", "group__DRV__QSPI__MODULE.html#gaada781787ade5549173b7fd1cf19ddaf", null ],
    [ "QSPI_TRANSFER_FAILED", "group__DRV__QSPI__MODULE.html#gaad03c1c3a8b82bebb93cb51e273b79c2", null ],
    [ "QSPI_TRANSFER_CSN_DEASSERT", "group__DRV__QSPI__MODULE.html#ga3d512210a36aa93dde4934f8a39f0064", null ],
    [ "QSPI_TRANSFER_TIMEOUT", "group__DRV__QSPI__MODULE.html#ga28b0df7988185754e238242371bfb810", null ],
    [ "QSPI_Handle", "group__DRV__QSPI__MODULE.html#ga5bee361334c18edf336f41021c1c3513", null ],
    [ "QSPI_init", "group__DRV__QSPI__MODULE.html#ga1d19b7d7d62bf4434e0246095477f2b4", null ],
    [ "QSPI_deinit", "group__DRV__QSPI__MODULE.html#ga5c3ae76d3a0f2a6ea6ed1ac332d397b9", null ],
    [ "QSPI_Params_init", "group__DRV__QSPI__MODULE.html#ga1d6f4702b4a903b2f907789a59f5b87b", null ],
    [ "QSPI_open", "group__DRV__QSPI__MODULE.html#ga4ca75fea87230420859b5c8128492905", null ],
    [ "QSPI_close", "group__DRV__QSPI__MODULE.html#ga6d5f30a61e058ccd98e1c55439cc7c35", null ],
    [ "QSPI_getHandle", "group__DRV__QSPI__MODULE.html#ga7abf12320af4df4096677c4a355a02ca", null ],
    [ "QSPI_getInputClk", "group__DRV__QSPI__MODULE.html#gaf55858a05c9f61da9ad705059c6e5020", null ],
    [ "QSPI_readMemMapMode", "group__DRV__QSPI__MODULE.html#ga6466fe94253ee22d728409ca52357e8c", null ],
    [ "QSPI_readConfigMode", "group__DRV__QSPI__MODULE.html#ga76eae97f37aa537590cb6c8967a7dde7", null ],
    [ "QSPI_writeCmd", "group__DRV__QSPI__MODULE.html#gae84861505dc2b319aa8920c451117521", null ],
    [ "QSPI_writeConfigMode", "group__DRV__QSPI__MODULE.html#gaf6cec49280fb8972a39aa54da1d1cb84", null ],
    [ "QSPI_writeConfigModeIntr", "group__DRV__QSPI__MODULE.html#ga5ae1a3f4eec8e62c942bf08031ea778e", null ],
    [ "QSPI_readCmd", "group__DRV__QSPI__MODULE.html#gafca35047faaeec5b1926054181caea65", null ],
    [ "QSPI_readConfigModeIntr", "group__DRV__QSPI__MODULE.html#ga59db9a6c7806bcad2b3f49e00a19fa8a", null ],
    [ "QSPI_transaction_init", "group__DRV__QSPI__MODULE.html#ga66127f46974f1cab51726fe65e45ad2b", null ],
    [ "QSPI_readCmdParams_init", "group__DRV__QSPI__MODULE.html#ga931d517d31412aa543d7e2e3cffbe14a", null ],
    [ "QSPI_writeCmdParams_init", "group__DRV__QSPI__MODULE.html#gaddaabb30a400f9e894dec38b85c820e3", null ],
    [ "QSPI_setPreScaler", "group__DRV__QSPI__MODULE.html#ga47e29eddcb2586a011365bd572c9fbf9", null ],
    [ "QSPI_setWriteCmd", "group__DRV__QSPI__MODULE.html#ga4a009c6e0dc8ce61dc79b1084ddabae8", null ],
    [ "QSPI_setReadCmd", "group__DRV__QSPI__MODULE.html#gab5269bbc4e7db9c81a92b567331d9f46", null ],
    [ "QSPI_setAddressByteCount", "group__DRV__QSPI__MODULE.html#ga0b2a9061d878871f6053a684700dd092", null ],
    [ "QSPI_setDummyBitCount", "group__DRV__QSPI__MODULE.html#gabb52dd394b88a692dd59bfb4474205ec", null ],
    [ "QSPI_setMemAddrSpace", "group__DRV__QSPI__MODULE.html#gae12db59fc3483c599ccaceebce20120d", null ],
    [ "QSPI_intEnable", "group__DRV__QSPI__MODULE.html#gae9d37319d0eb17cdc31949e6ed52a6b5", null ],
    [ "QSPI_intDisable", "group__DRV__QSPI__MODULE.html#ga2df1d404c0ba42e1f148a9f991407cda", null ],
    [ "QSPI_intClear", "group__DRV__QSPI__MODULE.html#gafcb59a900781476e8009553130846529", null ],
    [ "QSPI_setRxLines", "group__DRV__QSPI__MODULE.html#gaee55483cc68c6d1cf7e6c54b0f15cd5c", null ],
    [ "QSPI_getRxLines", "group__DRV__QSPI__MODULE.html#ga8e65cfdf9667880682291da055708b2c", null ],
    [ "OSPI_phyGetTuningData", "group__DRV__QSPI__MODULE.html#ga69d9a4b5df3d4a4f92321e77b2dc21e5", null ],
    [ "gQspiConfig", "group__DRV__QSPI__MODULE.html#ga883b4d2580730337ed7b9c755ce7a415", null ],
    [ "gQspiConfigNum", "group__DRV__QSPI__MODULE.html#gabc05cad3f8ccc0e25325ae6f30e97384", null ],
    [ "gqspiEdmaParam", "group__DRV__QSPI__MODULE.html#ga6d21797a0b97bfa05832b0bbd9622879", null ]
];
